@@ -8,20 +8,31 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
+imports_available = True
 try:
     import numpy as np
     import pandas as pd
     from scipy import stats
     import itertools
     from scipy.interpolate import griddata
+except ImportError:
+    imports_available = False
+
+try:
+    # matplotlib.pyplot can generate a runtime error on OSX when not
+    # installed as a Framework (as is the case in the CI systems)
+    #
+    # occasionally dependent conda packages for older distributions
+    # (e.g. python 3.5) get released that are either broken not
+    # compatible, resulting in a SyntaxError
     import seaborn as sns
     import matplotlib.pyplot as plt
     import matplotlib.tri as tri
     from matplotlib.lines import Line2D
-    imports_available = True
-except ImportError:
+except (ImportError, RuntimeError, SyntaxError):
     imports_available = False
 
+from pyomo.common.dependencies import check_min_version
 
 def _get_variables(ax,columns):
     sps = ax.get_subplotspec()
@@ -83,15 +94,16 @@ def _get_data_slice(xvar,yvar,columns,data,theta_star):
     
     return X,Y,Z
     
-
-def _add_scatter(x,y,color,label,columns,theta_star):
+# Note: seaborn 0.11 no longer expects color and label to be passed to the 
+#       plotting functions. label is kept here for backward compatibility
+def _add_scatter(x,y,color,columns,theta_star,label=None):
     ax = plt.gca()
     xvar, yvar, loc = _get_variables(ax, columns)
     
     ax.scatter(theta_star[xvar], theta_star[yvar], c=color, s=35)
     
     
-def _add_rectangle_CI(x,y,color,label,columns,lower_bound,upper_bound):
+def _add_rectangle_CI(x,y,color,columns,lower_bound,upper_bound,label=None):
     ax = plt.gca()
     xvar, yvar, loc = _get_variables(ax,columns)
 
@@ -106,7 +118,7 @@ def _add_rectangle_CI(x,y,color,label,columns,lower_bound,upper_bound):
     ax.plot([xmin, xmin], [ymax, ymin], color=color)
 
 
-def _add_scipy_dist_CI(x,y,color,label,columns,ncells,alpha,dist,theta_star):
+def _add_scipy_dist_CI(x,y,color,columns,ncells,alpha,dist,theta_star,label=None):
     ax = plt.gca()
     xvar, yvar, loc = _get_variables(ax,columns)
     
@@ -142,7 +154,7 @@ def _add_scipy_dist_CI(x,y,color,label,columns,ncells,alpha,dist,theta_star):
     ax.contour(X,Y,Z, levels=[alpha], colors=color) 
     
     
-def _add_obj_contour(x,y,color,label,columns,data,theta_star):
+def _add_obj_contour(x,y,color,columns,data,theta_star,label=None):
     ax = plt.gca()
     xvar, yvar, loc = _get_variables(ax,columns)
 
@@ -155,18 +167,6 @@ def _add_obj_contour(x,y,color,label,columns,data,theta_star):
         plt.tricontourf(triang,Z,cmap=cmap)
     except:
         print('Objective contour plot for', xvar, yvar,'slice failed')
-    
-    
-def _add_LR_contour(x,y,color,label,columns,data,theta_star,threshold):
-    ax = plt.gca()
-    xvar, yvar, loc = _get_variables(ax,columns)
-    
-    X, Y, Z = _get_data_slice(xvar,yvar,columns,data,theta_star)
-    
-    triang = tri.Triangulation(X, Y)
-    
-    plt.tricontour(triang,Z,[threshold], colors='r')
-
 
 def _set_axis_limits(g, axis_limits, theta_vals, theta_star):
     
@@ -216,7 +216,7 @@ def pairwise_plot(theta_values, theta_star=None, alpha=None, distributions=[],
         Statistical distribution used to define a confidence region, 
         options = 'MVN' for multivariate_normal, 'KDE' for gaussian_kde, and 
         'Rect' for rectangular.
-		Confidence interval is a 2D slice, using linear interpolation at theta*.
+        Confidence interval is a 2D slice, using linear interpolation at theta*.
     axis_limits: dict, optional
         Axis limits in the format {variable: [min, max]}
     title: string, optional
@@ -263,7 +263,13 @@ def pairwise_plot(theta_values, theta_star=None, alpha=None, distributions=[],
     g = sns.PairGrid(thetas)
     
     # Plot histogram on the diagonal
-    g.map_diag(sns.distplot, kde=False, hist=True, norm_hist=False) 
+    # Note: distplot is deprecated and will be removed in a future
+    #       version of seaborn, use histplot.  distplot is kept for older
+    #       versions of python.
+    if check_min_version(sns, "0.11"):
+        g.map_diag(sns.histplot)
+    else:
+        g.map_diag(sns.distplot, kde=False, hist=True, norm_hist=False) 
     
     # Plot filled contours using all theta values based on obj
     if 'obj' in theta_values.columns and add_obj_contour:
